@@ -1,5 +1,5 @@
 import pytest
-import jupyterlab_s3_browser_yq
+import jupyterlab_s3_browser
 from moto import mock_s3
 
 
@@ -9,11 +9,11 @@ from moto import mock_s3
 
 
 def test_not_has_aws_s3_role_access_when_unauthenticated():
-    if jupyterlab_s3_browser_yq.has_aws_s3_role_access():
+    if jupyterlab_s3_browser.has_aws_s3_role_access():
         pytest.fail("authenticated")
 
 
 @mock_s3
 def test_has_aws_s3_role_access_when_authenticated():
-    if not jupyterlab_s3_browser_yq.has_aws_s3_role_access():
+    if not jupyterlab_s3_browser.has_aws_s3_role_access():
         pytest.fail("not authenticated")
